% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gl.recode.ind.r
\name{gl.recode.ind}
\alias{gl.recode.ind}
\title{Recodes individual (=specimen = sample) labels in a genlight object}
\usage{
gl.recode.ind(x, ind.recode, recalc = FALSE, mono.rm = FALSE, verbose = NULL)
}
\arguments{
\item{x}{Name of the genlight object  [required].}

\item{ind.recode}{Name of the csv file containing the individual relabelling
[required].}

\item{recalc}{If TRUE, recalculate the locus metadata statistics if any 
individuals are deleted in the filtering [default FALSE].}

\item{mono.rm}{If TRUE, remove monomorphic loci [default FALSE].}

\item{verbose}{Verbosity: 0, silent or fatal errors; 1, begin and end; 2, 
progress log; 3, progress and results summary; 5, full report 
[default 2 or as specified using gl.set.verbosity].}
}
\value{
A genlight or genind object with the recoded and reduced data.
}
\description{
This function recodes individual labels and/or deletes individuals from a DaRT
genlight SNP file based on a lookup table provided as a csv file.
}
\details{
Renaming individuals may be required when there have been errors in labeling
arising in the process from sample to sequence files. There may be occasions
where renaming individuals is required for preparation of figures. When
caution needs to be exercised because of the potential for breaking the
'chain of evidence' associated with the samples, recoding individuals using
a recode table (csv) can provide a durable record of the changes.
The function works with genlight objects
containing SNP genotypes and Tag P/A data (SilicoDArT).
For SNP genotype data, the function, having deleted individuals, optionally 
identifies resultant monomorphic loci or loci with all values missing 
and deletes them. The script also optionally recalculates the
locus metadata as appropriate. The optional deletion of monomorphic loci
and the optional recalculation of locus statistics is not available for
Tag P/A data (SilicoDArT).
The script returns a dartR genlight object with the new individual names  
and the recalculated locus metadata.
}
\examples{
  file <- system.file('extdata','testset_ind_recode.csv', package='dartR.data')
  gl <- gl.recode.ind(testset.gl, ind.recode=file, verbose=3)
  
}
\seealso{
\code{\link{gl.filter.monomorphs}} for filtering monomorphs,
 \code{\link{gl.recalc.metrics}} for recalculating locus metrics,
\code{\link{gl.recode.pop}} for recoding populations

Other data manipulation: 
\code{\link{gl.define.pop}()},
\code{\link{gl.drop.ind}()},
\code{\link{gl.drop.loc}()},
\code{\link{gl.drop.pop}()},
\code{\link{gl.edit.recode.pop}()},
\code{\link{gl.impute}()},
\code{\link{gl.join}()},
\code{\link{gl.keep.ind}()},
\code{\link{gl.keep.loc}()},
\code{\link{gl.keep.pop}()},
\code{\link{gl.make.recode.ind}()},
\code{\link{gl.merge.pop}()},
\code{\link{gl.reassign.pop}()},
\code{\link{gl.recode.pop}()},
\code{\link{gl.rename.pop}()},
\code{\link{gl.sample}()},
\code{\link{gl.sim.genotypes}()},
\code{\link{gl.sort}()},
\code{\link{gl.subsample.ind}()},
\code{\link{gl.subsample.loc}()}
}
\author{
Custodian: Arthur Georges -- Post to
\url{https://groups.google.com/d/forum/dartr}
}
\concept{data manipulation}
